==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/ReleaseAddressRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.AllocationId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ReleaseAddressRequest(
    allocationId: Optional[AllocationId] = Optional.Absent,
    publicIp: Optional[String] = Optional.Absent,
    networkBorderGroup: Optional[String] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest = {
    import ReleaseAddressRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
      .builder()
      .optionallyWith(
        allocationId.map(value => AllocationId.unwrap(value): java.lang.String)
      )(_.allocationId)
      .optionallyWith(publicIp.map(value => value: java.lang.String))(
        _.publicIp
      )
      .optionallyWith(networkBorderGroup.map(value => value: java.lang.String))(
        _.networkBorderGroup
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ReleaseAddressRequest.ReadOnly =
    zio.aws.ec2.model.ReleaseAddressRequest.wrap(buildAwsValue())
}
object ReleaseAddressRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ReleaseAddressRequest =
      zio.aws.ec2.model.ReleaseAddressRequest(
        allocationId.map(value => value),
        publicIp.map(value => value),
        networkBorderGroup.map(value => value),
        dryRun.map(value => value)
      )
    def allocationId: Optional[AllocationId]
    def publicIp: Optional[String]
    def networkBorderGroup: Optional[String]
    def dryRun: Optional[Boolean]
    def getAllocationId: ZIO[Any, AwsError, AllocationId] =
      AwsError.unwrapOptionField("allocationId", allocationId)
    def getPublicIp: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("publicIp", publicIp)
    def getNetworkBorderGroup: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("networkBorderGroup", networkBorderGroup)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
  ) extends zio.aws.ec2.model.ReleaseAddressRequest.ReadOnly {
    override val allocationId: Optional[AllocationId] = zio.aws.core.internal
      .optionalFromNullable(impl.allocationId())
      .map(value => zio.aws.ec2.model.primitives.AllocationId(value))
    override val publicIp: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.publicIp())
      .map(value => value: String)
    override val networkBorderGroup: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.networkBorderGroup())
      .map(value => value: String)
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
  ): zio.aws.ec2.model.ReleaseAddressRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.124.3-sources.jar: zio/aws/ec2/model/ReleaseAddressRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.AllocationId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ReleaseAddressRequest(
    allocationId: Option[AllocationId] = None,
    publicIp: Option[String] = None,
    networkBorderGroup: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest = {
    import ReleaseAddressRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
      .builder()
      .optionallyWith(
        allocationId.map(value => AllocationId.unwrap(value): java.lang.String)
      )(_.allocationId)
      .optionallyWith(publicIp.map(value => value: java.lang.String))(
        _.publicIp
      )
      .optionallyWith(networkBorderGroup.map(value => value: java.lang.String))(
        _.networkBorderGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ReleaseAddressRequest.ReadOnly =
    zio.aws.ec2.model.ReleaseAddressRequest.wrap(buildAwsValue())
}
object ReleaseAddressRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ReleaseAddressRequest =
      zio.aws.ec2.model.ReleaseAddressRequest(
        allocationId.map(value => value),
        publicIp.map(value => value),
        networkBorderGroup.map(value => value)
      )
    def allocationId: Option[AllocationId]
    def publicIp: Option[String]
    def networkBorderGroup: Option[String]
    def getAllocationId: ZIO[Any, AwsError, AllocationId] =
      AwsError.unwrapOptionField("allocationId", allocationId)
    def getPublicIp: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("publicIp", publicIp)
    def getNetworkBorderGroup: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("networkBorderGroup", networkBorderGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
  ) extends zio.aws.ec2.model.ReleaseAddressRequest.ReadOnly {
    override val allocationId: Option[AllocationId] = scala
      .Option(impl.allocationId())
      .map(value => zio.aws.ec2.model.primitives.AllocationId(value))
    override val publicIp: Option[String] =
      scala.Option(impl.publicIp()).map(value => value: String)
    override val networkBorderGroup: Option[String] =
      scala.Option(impl.networkBorderGroup()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseAddressRequest
  ): zio.aws.ec2.model.ReleaseAddressRequest.ReadOnly = new Wrapper(impl)
}
